@@ -346,7 +346,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 	 -q and -e.  */
 #if (defined (sun) || defined (__sun)) && defined (__SVR4)
       if ((strcmp (grep_path, "/usr/bin/grep") == 0
-	   || strcmp (grep_path, "/bin/grep") == 0))
+	   || strcmp (grep_path, "/bin/grep") == 0)
 	  && access ("/usr/xpg4/bin/grep", X_OK) == 0)
 	grep_path = "/usr/xpg4/bin/grep";
 #endif
